:math:`\frac{\log 23}{\pi}`
:ref:`my_label`

.. math::
    :label: my_label
      
    \pi \neq \sigma

.. latex::
    :usepackage: url
            
    \emph{a link} \url{http://muralab.org/rstex}
        
